@@ -37,6 +37,8 @@
       (guava-themes-acer-black             "#000000")
       (guava-themes-acer-white             "#FFFFFF")
 
+      (guava-themes-acer-shadow            "#7f7f7f")
+
       (guava-themes-acer-cream             "#dc8e64"); f68e64
 
       (guava-themes-acer-deep-green        "#239834")
@@ -89,8 +91,11 @@
    `(line-number ((,guava-themes-acer-class (:foreground ,guava-themes-acer-black :height 1.35))))
    `(line-number-current-line ((,guava-themes-acer-class (:foreground ,guava-themes-acer-red :background ,guava-themes-acer-cream :weight bold :height 1.35))))
 
-   ;; hl-line
-   `(hl-line ((,guava-themes-acer-class (:background ,guava-themes-acer-cream))))
+   ;; highlight
+   `(highlight ((,guava-themes-acer-class (:background ,guava-themes-acer-cream))))
+
+   ;; shadow
+   `(shadow ((,guava-themes-acer-class (:foreground ,guava-themes-acer-shadow))))
 
    ;; region
    `(region ((,guava-themes-acer-class (:background ,guava-themes-acer-deep-orange))))
