@@ -37,6 +37,8 @@
       (guava-themes-citrus-black                   "#000000")
       (guava-themes-citrus-white                   "#f1f0f5");FFFFFF,eeeeee,f0eff5
 
+      (guava-themes-citrus-shadow                  "#7f7f7f")
+
       (guava-themes-citrus-lime-green              "#589337");589337
       (guava-themes-citrus-green                   "#136b16")
 
@@ -85,8 +87,11 @@
    `(line-number ((,guava-themes-citrus-class (:foreground ,guava-themes-citrus-black :height 1.35))))
    `(line-number-current-line ((,guava-themes-citrus-class (:foreground ,guava-themes-citrus-green :background ,guava-themes-citrus-lemon-light-yellow :weight bold :height 1.35))))
 
-   ;; hl-line
-   `(hl-line ((,guava-themes-citrus-class (:background ,guava-themes-citrus-lemon-light-yellow))))
+   ;; highlight
+   `(highlight ((,guava-themes-citrus-class (:background ,guava-themes-citrus-lemon-light-yellow))))
+
+   ;; shadow
+   `(shadow ((,guava-themes-citrus-class (:foreground ,guava-themes-citrus-shadow))))
 
    ;; region
    `(region ((,guava-themes-citrus-class (:background ,guava-themes-citrus-lemon-yellow))))
@@ -137,9 +142,7 @@
    ;; buttons
    `(link ((,guava-themes-citrus-class (:foreground ,guava-themes-citrus-light-blue :underline t :weight bold))))
    `(link-visited ((,guava-themes-citrus-class (:foreground ,guava-themes-citrus-blue :underline t :weight bold))))
-   `(button ((,guava-themes-citrus-class (:foreground ,guava-themes-citrus-light-blue :underline t :weight bold))))
-   )
-  )
+   `(button ((,guava-themes-citrus-class (:foreground ,guava-themes-citrus-light-blue :underline t :weight bold))))))
 
 (provide-theme 'guava-themes-citrus)
 
