@@ -37,6 +37,8 @@
       (guava-themes-cordyline-black             "#000000")
       (guava-themes-cordyline-white             "#FFFFFF")
 
+      (guava-themes-cordyline-shadow            "#b3b3b3")
+
       (guava-themes-cordyline-pink              "#CB5F68")
       (guava-themes-cordyline-pink-purple       "#da70d6")
 
@@ -85,8 +87,11 @@
    `(line-number ((,guava-themes-cordyline-class (:foreground ,guava-themes-cordyline-white :height 1.35))))
    `(line-number-current-line ((,guava-themes-cordyline-class (:foreground ,guava-themes-cordyline-light-blue :background ,guava-themes-cordyline-alt-purple :weight bold :height 1.35))))
 
-   ;; hl-line
-   `(hl-line ((,guava-themes-cordyline-class (:background ,guava-themes-cordyline-alt-purple))))
+   ;; highlight
+   `(highlight ((,guava-themes-cordyline-class (:background ,guava-themes-cordyline-alt-purple))))
+
+   ;; shadow
+   `(shadow ((,guava-themes-cordyline-class (:foreground ,guava-themes-cordyline-shadow))))
 
    ;; region
    `(region ((,guava-themes-cordyline-class (:background ,guava-themes-cordyline-dark-purple))))
