@@ -35,8 +35,10 @@
 (let* (
       (guava-themes-jacaranda-class '((class color) (min-colors 257)))
       (guava-themes-jacaranda-black             "#000000")
-
       (guava-themes-jacaranda-white             "#FFFFFF")
+
+      (guava-themes-jacaranda-shadow            "#7f7f7f")
+
       (guava-themes-jacaranda-cream             "#e9d9f9");e9e4f9
 
       (guava-themes-jacaranda-light-green       "#52bc63")
@@ -91,8 +93,11 @@
    `(line-number ((,guava-themes-jacaranda-class (:foreground ,guava-themes-jacaranda-antarctic-blue :height 1.35))))
    `(line-number-current-line ((,guava-themes-jacaranda-class (:foreground ,guava-themes-jacaranda-black :background ,guava-themes-jacaranda-light-purple :weight bold :height 1.35))))
 
-   ;; hl-line
-   `(hl-line ((,guava-themes-jacaranda-class (:background ,guava-themes-jacaranda-light-purple))))
+   ;; highlight
+   `(highlight ((,guava-themes-jacaranda-class (:background ,guava-themes-jacaranda-light-purple))))
+
+   ;; shadow
+   `(shadow ((,guava-themes-jacaranda-class (:foreground ,guava-themes-jacaranda-shadow))))
 
    ;; region
    `(region ((,guava-themes-jacaranda-class (:background ,guava-themes-jacaranda-light-blue))))
